@@ -264,7 +264,7 @@ class DataCounterResetter(QtGui.QWidget):
                 i = self.eventProfile.findText(
                  self.eventList.currentItem().eventInfo["content"])
                 if i == -1:
-                    self.showError('''<font color="#000000">This event has become invalid because tweakr is not installed!</font>''')
+                    self.showError('''<font color="#000000">This event has become invalid because you (un)installed tweakr.</font>''')
                 self.eventProfile.setCurrentIndex(i)
                 self.eventProfile.show()
             self.eventName.setText(
